@@ -1,13 +1,13 @@
 #' Get log file paths for jobs.
-#' @param reg [\code{\link{Registry}}]\cr
-#'   Registry.
+#' @template arg_reg
 #' @param ids [\code{integer}]\cr
 #'   Ids of jobs.
 #'   Default is all jobs.
 #' @return [\code{character}]. Vector of file paths to log files.
+#' @family debug
 #' @export
 getLogFiles = function(reg, ids) {
-  checkRegistry(reg)
+  checkRegistry(reg, writeable = FALSE)
   syncRegistry(reg)
   if (missing(ids))
     ids = getJobIds(reg)
