@@ -1,4 +1,5 @@
 library(BBmisc)
+library(checkmate)
 options(BBmisc.ProgressBar.style = "off")
 options(BatchJobs.verbose = FALSE)
 
@@ -27,7 +28,7 @@ getTempDir = function() {
 }
 
 makeTestRegistry = function(packages = character(0L), work.dir = getWorkDir(), file.dir = getTempDir(), ...) {
-  dir.create(file.dir, recursive = TRUE, showWarning = FALSE)
+  dir.create(file.dir, recursive = TRUE, showWarnings = FALSE)
   makeRegistry(
     id = "unittests",
     seed = 1L,
